//
//  AliWhiteboard.h
//
//  Created by 薛林 on 2020/12/29.
//  Copyright © 2020 Alibaba Group. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <WebKit/WebKit.h>
NS_ASSUME_NONNULL_BEGIN

/// 回调protocol
@protocol AliWhiteboardDelegate <NSObject>
#define kEventBoardCreated   @"E_BoardCreated"
#define kEventBoardDestroyed @"E_BoardDestroyed"
@required
- (void)eventNotify:(NSString *)eventName session:(NSString *)session eventData:(NSString *)eventData;
- (NSDictionary *)onEventDataGotten:(NSString *)eventName data:(NSDictionary*)dicData;
@end

@interface WhiteboardConfig : NSObject
@property (nonatomic, strong) NSString* configData;
@property (nonatomic, strong) NSString* docData;
@end

/// 白板功能类
@interface AliWhiteboard : WKWebView

- (instancetype)initWithConfig:(WhiteboardConfig *)boardConfig
                 eventDelegate:(id<AliWhiteboardDelegate>) eventDelegate
                         frame:(CGRect)frame;

/// @param methodName 需要被执行方法名
/// @param completionHandler 方法结果
- (void)invokeAPI:(NSString *)methodName completionHandler:(void (^_Nullable)(NSString * response))completionHandler;

/// @param methodName 需要被执行方法名
/// @param parameter 方法对应的参数
/// @param completionHandler 方法结果
- (void)invokeAPI:(NSString *)methodName parameter:(NSString *)parameter completionHandler:(void (^_Nullable)(NSString * response))completionHandler;

/// @param methodName 需要被异步执行方法名
/// @param parameter 方法对应的参数
/// @param completionHandler 方法结果
- (void)invokeAPIAsync:(NSString *)methodName parameter:(NSString *)parameter session:(NSString*)session completionHandler:(void (^_Nullable)(NSString * response))completionHandler;

/// SDK版本
+ (NSString *)sdkVersion;
@end

NS_ASSUME_NONNULL_END
